local name, addon = ...
local modName = "autogreed"
local message = {
  ["enUS"] = "Greed or disentchant blue and green",
  ["deDE"] = "Gier/Entzaubern von gr\195\188nem/blauem Loot"
}
addon['mhmods'] = addon['mhmods'] or {}

local orbList = {
	[45087] = true, -- runed orb
	[52078] = true, -- chaos orb
}

local defaults = {
		['deGreen'] = true,
		['passGreen'] = false,
		['deBlue'] = true,
		['passBlue'] = false,
		['deEpic'] = false,
		['passEpic'] = false,
		['skipNeed'] = true,
		['ignoreOrbs'] = true,
		['showBOE'] = 2,
		['skipQuality'] = 0,
		['skipQuest'] = true,
		['skipPet'] = true,
		['skipMount'] = true,
		['skipHoliday'] = true,
}
local options

local function getPref2(key)
	local db = addon['MH_GetDB'](modName, defaults)
	return db[key]
end

local function getPref(pref)
	return getPref2(pref[#pref])
end

local function setPref(pref,value)
	local db = addon['MH_GetDB'](modName, defaults)
	db[pref[#pref]] = value
end

local function checkPrefType(key, prefType)
	local db = addon['MH_GetDB'](modName, defaults)
	if(type(getPref2(key)) ~= prefType) then
		db[key] = defaults[key]
	end
end

local function initDBCheck()
	for key,value in pairs(defaults) do
		checkPrefType(key, type(defaults[key]))
	end
end

local qualityTab = {'','Green','Blue','Epic','Legendary'}

local function START_LOOT_ROLL(event,id,...)
	if (not id) then return	end
	if(getPref2('ignoreOrbs') and orbList[tonumber(addon:getItemId(GetLootRollItemLink(id)))]) then return end
	local _, _, _, quality, bop, canNeed, canGreed, canDE = GetLootRollItemInfo(id)
	local showNeed = getPref2('skipQuality') >= 0 and getPref2('skipQuality') or (GetAverageItemLevel() - 18)
	local _,_,_,itemLevel,_,_,_,_,_,_,_, classID, subclassID = GetItemInfo(GetLootRollItemLink(id))
	if(classID == 12 and getPref2('skipQuest')) then
		return
	elseif(classID == 15) then
		if(subclassID == 5 and getPref2('skipMount')) then
			return
		elseif(subclassID == 2 and getPref2('skipPet')) then
			return
		elseif(subclassID == 3 and getPref2('skipHoliday')) then
			return
		end
	end
	if(canNeed and bop and getPref2('skipNeed')) then
		if(showNeed < itemLevel) then
			return
		end
	end
	local arg1,arg2 = canDE and 3 or 2, 2
	if(bop) then
		RollOnLoot(id,getPref2('de'..qualityTab[quality]) and arg1 or arg2)
	else
		if(canNeed and quality>getPref2('showBOE') and getPref2('skipNeed')) then return end
		if(getPref2('greedBOE')) then
			RollOnLoot(id,getPref2('pass'..qualityTab[quality]) and nil or (quality==2 and arg1 or arg2))
		else
			RollOnLoot(id,arg1 == 3 and 3 or (getPref2('pass'..qualityTab[quality]) and nil or arg1))
		end
	end
end

addon['mhmods'][#addon['mhmods'] + 1] = {
	['name'] = modName,
	['message'] = message[GetLocale()] or message["enUS"],
	['events'] = { "START_LOOT_ROLL" },
	['onevent'] = START_LOOT_ROLL,
	['init'] = function()
		options = addon['MH_GetOptions']()
		initDBCheck()
		local grp = addon:AddConfigMenu({['name'] = modName, ['order'] = 20,['menuGet'] = getPref, ['menuSet'] = setPref},options)
		addon:AddConfigEntry("zz_MiscHelper","header","disenchant","Disenchant",nil,1,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","deGreen","DE green",nil,2,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","deBlue","DE blue",nil,3,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","deEpic","DE epic",nil,4,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","header","boe","Bind on Equip",nil,5,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","greedBOE","Greed BoE",nil,6,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","range","showBOE","Show BoE",format("1, |c%s2|r, |c%s3|r, |c%s4|r Skip greeding BoE when quality is higher",select(4,GetItemQualityColor(2)),select(4,GetItemQualityColor(3)),select(4,GetItemQualityColor(4))),7,1,4,1,false,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","passGreen","Pass green BoE",nil,8,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","passBlue","Pass blue BoE",nil,9,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","passEpic","Pass epic BoE",nil,10,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","header","misc","Misc",nil,11,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","skipNeed","Show Need Rolls","Show items you can roll need for. Set minimum quality to hide low level items.",12,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","range","skipQuality","Minimum Quality","Dont show items with a quality lower than minimum quality when 'Show Need Rolls' is active. -1 means automagically your current average Itemlevel - 18",13,-1,1000,1,false,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","ignoreOrbs","Ignore orbs",nil,14,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","skipPet","Show Pets",nil,15,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","skipMount","Show Mounts",nil,16,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","skipHoliday","Show Holiday-Items",nil,17,nil,nil,nil,nil,grp)
		addon:AddConfigEntry("zz_MiscHelper","toggle","skipQuest","Show Questitems",nil,17,nil,nil,nil,nil,grp)
	end,
}